@@ -185,7 +185,9 @@ loadPlaylist = loadPlaylistWith isPrefixOf
 -- @since 0.13.2
 addAndPlayAny :: RunMPD -> XPConfig -> [Metadata] -> X ()
 addAndPlayAny runMPD xp metas = do
-#if MIN_VERSION_xmonad_contrib(0,16,9)
+#if MIN_VERSION_xmonad_contrib(0,18,1)
+  hist <- historyCompletionP xp (showXPrompt (MPDPrompt "Search: ") ==)
+#elif MIN_VERSION_xmonad_contrib(0,16,9)
   hist <- historyCompletionP (showXPrompt (MPDPrompt "Search: ") ==)
 #else
   let hist = historyCompletionP (showXPrompt (MPDPrompt "Search: ") ==)
